@@ -40,7 +40,7 @@ using namespace KPIM;
 namespace KPIM {
 class Q_DECL_HIDDEN KCheckComboBox::Private
 {
-    KCheckComboBox *q;
+    KCheckComboBox *q = nullptr;
 
 public:
     Private(KCheckComboBox *qq)
@@ -138,11 +138,16 @@ KCheckComboBox::KCheckComboBox(QWidget *parent)
     : KComboBox(parent)
     , d(new KCheckComboBox::Private(this))
 {
-    connect(this, SIGNAL(activated(int)), this, SLOT(toggleCheckState()));
-    connect(model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-            SLOT(makeInsertedItemsCheckable(QModelIndex,int,int)));
-    connect(model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            this, SLOT(updateCheckedItems(QModelIndex,QModelIndex)));
+    connect(this, QOverload<int>::of(&KComboBox::activated), this, [this]() {
+        d->toggleCheckState();
+    });
+    connect(model(), &QAbstractItemModel::rowsInserted, this,
+            [this](const QModelIndex &index, int start, int end) {
+        d->makeInsertedItemsCheckable(index, start, end);
+    });
+    connect(model(), &QAbstractItemModel::dataChanged, this, [this](const QModelIndex &topLeft, const QModelIndex &bottomRight) {
+        d->updateCheckedItems(topLeft, bottomRight);
+    });
 
     // read-only contents
     setEditable(true);
