@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -43,7 +43,7 @@ Q_SIGNALS:
 
 private:
     QString mSearchEmail;
-    int mLimit;
+    int mLimit = 500;
 };
 }
 
